summaryrefslogtreecommitdiff
path: root/flexdef.h
diff options
context:
space:
mode:
authorJohn Millaway <john43@users.sourceforge.net>2002-09-13 01:17:22 +0000
committerJohn Millaway <john43@users.sourceforge.net>2002-09-13 01:17:22 +0000
commit815fd665d8c46fc9f106fe65643c12614ffc9747 (patch)
treeb1135a92b387ceb3d8629464bc0b57261d51343d /flexdef.h
parentf6904782ed84d7a946ecca17c1b1269eee0978c0 (diff)
Bison bridge code now works for all C scanners and pure/non-pure bison parsers.
Added %option bison-bridge (--bison-bridge). Removed %option reentrant-bison/--reentrant-bison/-Rb. Scanner knows the name of its tables. Tables serialization is OK on EOF. yylineno is present in all scanners. Modified nasty performance penalty warning w/ yylineno. test-table-opts is now run last because it's so fat. Updated manual.
Diffstat (limited to 'flexdef.h')
-rw-r--r--flexdef.h4
1 files changed, 2 insertions, 2 deletions
diff --git a/flexdef.h b/flexdef.h
index ad346c1..84867b2 100644
--- a/flexdef.h
+++ b/flexdef.h
@@ -413,7 +413,7 @@ __extension__ typedef unsigned long long int uint64_t;
* C_plus_plus - if true (i.e., -+ flag), generate a C++ scanner class;
* otherwise, a standard C scanner
* reentrant - if true (-R), generate a reentrant C scanner.
* reentrant_bison_pure - if true (-Rb), bison pure calling convention.
* long_align - if true (-Ca flag), favor long-word alignment.
* use_read - if true (-f, -F, or -Cr) then use read() for scanner input;
* otherwise, use fread().
@@ -440,7 +440,7 @@ extern int printstats, syntaxerror, eofseen, ddebug, trace, nowarn,
extern int interactive, caseins, lex_compat, posix_compat, do_yylineno;
extern int useecs, fulltbl, usemecs, fullspd;
extern int gen_line_dirs, performance_report, backing_up_report;
-extern int reentrant, reentrant_bison_pure;
+extern int reentrant, bison_bridge;
extern int C_plus_plus, long_align, use_read, yytext_is_array, do_yywrap;
extern int csize;
extern int yymore_used, reject, real_reject, continued_action, in_rule;
@@ -413,7 +413,7 @@ __extension__ typedef unsigned long long int uint64_t;
* otherwise, a standard C scanner
* reentrant - if true (-R), generate a reentrant C scanner.
- * reentrant_bison_pure - if true (-Rb), bison pure calling convention.
+ * bison_bridge - if true (--bison-bridge), bison pure calling convention.
* long_align - if true (-Ca flag), favor long-word alignment.
* use_read - if true (-f, -F, or -Cr) then use read() for scanner input;